#
# (C) Copyright Cloudlab URV 2020
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import os

COMPUTE_CLI_MSG = "{} client created"

HOME_DIR = os.path.expanduser("~")
CONFIG_DIR = os.path.join(HOME_DIR, ".skyplane")
CACHE_DIR = os.path.join(CONFIG_DIR, "cache")
CONFIG_FILE = os.path.join(CONFIG_DIR, "config")
CONFIG_FILE_GLOBAL = os.path.join("/etc", "lithops", "config")
